import type { Export, ExportDescriptor, FunctionType, GlobalType, MemoryType, TableType } from './reader/types.js';
import type { ModuleExport, ModuleFunction, ModuleGlobal, ModuleImport, ModuleMemory, ModuleSymbol, ModuleTable } from './types.js';
/**
 * Class representing a WebAssembly Module.
 */
export declare class Module {
    private importsByType;
    /**
     * An array of module functions.
     */
    functions: ModuleFunction[];
    /**
     * An array of global variables in the module.
     */
    globals: ModuleGlobal[];
    /**
     * An array of tables in the module.
     */
    tables: ModuleTable[];
    /**
     * An array of memory blocks in the module.
     */
    memories: ModuleMemory[];
    /**
     * An array of module imports.
     */
    imports: ModuleImport[];
    /**
     * An array of module exports.
     */
    exports: ModuleExport[];
    constructor(buffer: ArrayBuffer);
    addFunction(funcType: FunctionType): void;
    addFunctions(funcTypes: FunctionType[]): void;
    addGlobal(global: GlobalType): void;
    addGlobals(globals: GlobalType[]): void;
    addTable(table: TableType): void;
    addTables(tables: TableType[]): void;
    addMemory(memory: MemoryType): void;
    addMemories(memories: MemoryType[]): void;
    addImport(imp: ModuleImport): void;
    addImports(imports: ModuleImport[]): void;
    addExport(exported: Export): void;
    addExports(exports: Export[]): void;
    /**
     * Resolves an export descriptor to its corresponding module symbol.
     *
     * @param descriptor - The export descriptor indicating the type and index of the export.
     * @return The resolved module symbol if found, otherwise undefined.
     */
    resolveExportDescriptor(descriptor: ExportDescriptor): ModuleSymbol | undefined;
}
//# sourceMappingURL=module.d.ts.map