import { BinaryReader } from '@callstack/polygen-binary-utils';
/**
 * Reads and verifies the magic number from the binary data to ensure it represents a valid
 * WebAssembly module.
 *
 * @param reader - An instance of BinaryReader that provides methods to read bytes from binary data.
 * @returns Throws a WebAssemblyDecodeError if the magic number does not match the expected value.
 */
export declare function readMagic(reader: BinaryReader): void;
/**
 * Reads and returns a 32-bit unsigned integer representing the version
 * from the provided BinaryReader instance.
 *
 * @param reader The BinaryReader instance from which the version is read.
 * @return The version as a 32-bit unsigned integer.
 */
export declare function readVersion(reader: BinaryReader): number;
/**
 * Reads a raw WebAssembly module from the provided ArrayBuffer.
 *
 * This function utilizes a generator to iterate over the sections of the module.
 *
 * @param data - The ArrayBuffer containing the binary representation of the WebAssembly module.
 * @return A generator that yields sections of the WebAssembly module.
 */
export declare function readModuleRaw(data: ArrayBuffer): Generator<import("./types.js").Section, void, any>;
//# sourceMappingURL=module-reader.d.ts.map